@@ -229,10 +229,11 @@ cluster_opts = [
                       "network connection")),
 ]
 
+
 nsx_common_opts = [
     cfg.StrOpt('nsx_l2gw_driver',
                help=_("Specify the class path for the Layer 2 gateway "
-                      "backend driver(i.e. NSXv3/NSX-V). This field will be "
+                      "backend driver (i.e. NSX-T/NSX-V). This field will be "
                       "used when a L2 Gateway service plugin is configured.")),
     cfg.StrOpt('locking_coordinator_url',
                help=_("(Optional) URL for distributed locking coordination "
@@ -245,14 +246,23 @@ nsx_common_opts = [
                 help=_("If true, the server then allows the caller to "
                        "specify the id of resources. This should only "
                        "be enabled in order to allow one to migrate an "
-                       "existing install of neutron to the nsx-v3 plugin.")),
+                       "existing install of neutron to the NSX-T plugin.")),
     cfg.ListOpt('nsx_extension_drivers',
                 default=[],
                 help=_("An ordered list of extension driver "
                        "entrypoints to be loaded from the "
                        "vmware_nsx.extension_drivers namespace.")),
+    cfg.StrOpt('smtp_gateway',
+               help=_("(Optional) IP address of SMTP gateway to use for"
+                      "admin warnings.")),
+    cfg.StrOpt('smtp_from_addr',
+               help=_("(Optional) email address to use for outgoing admin"
+                      "notifications.")),
+    cfg.ListOpt('snmp_to_list',
+                default=[],
+                help=_("(Optional) List of email addresses for "
+                       "notifications.")),
 ]
-
 nsx_v3_opts = [
     cfg.ListOpt('nsx_api_user',
                 default=['admin'],
@@ -438,6 +448,30 @@ nsx_v3_opts = [
                 default=False,
                 help=_("(Optional) Indicates whether ENS transport zones can "
                        "be used")),
+    cfg.ListOpt('network_vlan_ranges',
+                default=[],
+                help=_("List of <TZ UUID>:<vlan_min>:<vlan_max> "
+                       "specifying Transport Zone UUID usable for VLAN "
+                       "provider networks, as well as ranges of VLAN "
+                       "tags on each available for allocation to networks.")),
+    cfg.BoolOpt('disable_port_security_for_ens',
+                default=False,
+                help=_("When True, port security will be set to False for "
+                       "newly created ENS networks and ports, overriding "
+                       "user settings")),
+    cfg.ListOpt('housekeeping_jobs',
+                default=['orphaned_dhcp_server', 'orphaned_logical_switch',
+                         'orphaned_logical_router', 'mismatch_logical_port',
+                         'orphaned_firewall_section'],
+                help=_("List of the enabled housekeeping jobs")),
+    cfg.ListOpt('housekeeping_readonly_jobs',
+                default=[],
+                help=_("List of housekeeping jobs which are enabled in read "
+                       "only mode")),
+    cfg.BoolOpt('housekeeping_readonly',
+                default=True,
+                help=_("Housekeeping will only warn about breakage.")),
+
 ]
 
 DEFAULT_STATUS_CHECK_INTERVAL = 2000
@@ -710,7 +744,8 @@ nsxv_opts = [
                 help=_("If False, different tenants will not use the same "
                        "DHCP edge or router edge.")),
     cfg.ListOpt('housekeeping_jobs',
-                default=['error_dhcp_edge', 'error_backup_edge'],
+                default=['error_dhcp_edge', 'error_backup_edge',
+                         'lbaas_pending'],
                 help=_("List of the enabled housekeeping jobs")),
     cfg.ListOpt('housekeeping_readonly_jobs',
                 default=[],
@@ -723,6 +758,10 @@ nsxv_opts = [
                 default=False,
                 help=_("Use default block all rule when no security groups "
                        "are set on a port and port security is enabled")),
+    cfg.BoolOpt('use_routers_as_lbaas_platform',
+                default=False,
+                help=_("Use subnet's exclusive router as a platform for "
+                       "LBaaS")),
 ]
 
 # define the configuration of each NSX-V availability zone.
@@ -835,6 +874,10 @@ nsxv3_az_opts = [
                help=_("(Optional) This is the name or UUID of the NSX dhcp "
                       "relay service that will be used to enable DHCP relay "
                       "on router ports.")),
+    cfg.StrOpt('default_tier0_router',
+               help=_("Name or UUID of the default tier0 router that will be "
+                      "used for connecting to tier1 logical routers and "
+                      "configuring external networks")),
 ]
 
 nsx_tvd_opts = [
@@ -858,6 +901,12 @@ nsx_tvd_opts = [
                choices=projectpluginmap.VALID_TYPES,
                help=_("The default plugin that will be used for new projects "
                       "that were not added to the projects plugin mapping.")),
+    cfg.ListOpt('enabled_plugins',
+                default=[projectpluginmap.NsxPlugins.NSX_T,
+                         projectpluginmap.NsxPlugins.NSX_V,
+                         projectpluginmap.NsxPlugins.DVS],
+                help=_("The list of plugins that the TVD core plugin will "
+                       "load")),
     cfg.ListOpt('nsx_v_default_availability_zones',
                 default=[],
                 help=_("The default availability zones that will be used for "
