@@ -127,7 +127,6 @@ class NsxPluginBase(db_base_plugin_v2.NeutronDbPluginV2,
         subnetpool = self.get_subnetpool(context, subnetpool_id)
         return subnetpool.get('address_scope_id', '')
 
-    # TODO(asarfaty): the NSX-V3 needs a very similar code too
     def _validate_address_scope_for_router_interface(self, context, router_id,
                                                      gw_network_id, subnet_id):
         """Validate that the GW address scope is the same as the interface"""
@@ -179,6 +178,21 @@ class NsxPluginBase(db_base_plugin_v2.NeutronDbPluginV2,
             device_id=device_id,
             device_owner=device_owner,).all()
 
+    def _update_filters_with_sec_group(self, context, filters=None):
+        if filters is not None:
+            security_groups = filters.pop("security_groups", None)
+            if security_groups:
+                bindings = (
+                    super(NsxPluginBase, self)
+                    ._get_port_security_group_bindings(context,
+                        filters={'security_group_id': security_groups}))
+                if 'id' in filters:
+                    filters['id'] = [entry['port_id'] for
+                                     entry in bindings
+                                     if entry['port_id'] in filters['id']]
+                else:
+                    filters['id'] = [entry['port_id'] for entry in bindings]
+
     def _find_router_subnets(self, context, router_id):
         """Retrieve subnets attached to the specified router."""
         ports = self._get_port_by_device_id(context, router_id,
@@ -191,7 +205,8 @@ class NsxPluginBase(db_base_plugin_v2.NeutronDbPluginV2,
                 subnet = subnet_qry.filter_by(id=ip.subnet_id).one()
                 subnets.append({'id': subnet.id, 'cidr': subnet.cidr,
                                 'subnetpool_id': subnet.subnetpool_id,
-                                'ip_version': subnet.ip_version})
+                                'ip_version': subnet.ip_version,
+                                'network_id': subnet.network_id})
         return subnets
 
     def _find_router_gw_subnets(self, context, router):
@@ -344,6 +359,48 @@ class NsxPluginBase(db_base_plugin_v2.NeutronDbPluginV2,
             err_msg = _("Can not enable DHCP on external network")
             raise n_exc.InvalidInput(error_message=err_msg)
 
+    def _validate_host_routes_input(self, subnet_input,
+                                    orig_enable_dhcp=None,
+                                    orig_host_routes=None):
+        s = subnet_input['subnet']
+        request_host_routes = (validators.is_attr_set(s.get('host_routes')) and
+                               s['host_routes'])
+        clear_host_routes = (validators.is_attr_set(s.get('host_routes')) and
+                             not s['host_routes'])
+        request_enable_dhcp = s.get('enable_dhcp')
+        if request_enable_dhcp is False:
+            if (request_host_routes or
+                not clear_host_routes and orig_host_routes):
+                err_msg = _("Can't disable DHCP while using host routes")
+                raise n_exc.InvalidInput(error_message=err_msg)
+
+        if request_host_routes:
+            if not request_enable_dhcp and orig_enable_dhcp is False:
+                err_msg = _("Host routes can only be supported when DHCP "
+                            "is enabled")
+                raise n_exc.InvalidInput(error_message=err_msg)
+
+    def get_housekeeper(self, context, name, fields=None):
+        # run the job in readonly mode and get the results
+        self.housekeeper.run(context, name, readonly=True)
+        return self.housekeeper.get(name)
+
+    def get_housekeepers(self, context, filters=None, fields=None, sorts=None,
+                         limit=None, marker=None, page_reverse=False):
+        return self.housekeeper.list()
+
+    def update_housekeeper(self, context, name, housekeeper):
+        # run the job in non-readonly mode and get the results
+        if not self.housekeeper.readwrite_allowed(name):
+            err_msg = (_("Can not run housekeeper job %s in readwrite "
+                         "mode") % name)
+            raise n_exc.InvalidInput(error_message=err_msg)
+        self.housekeeper.run(context, name, readonly=False)
+        return self.housekeeper.get(name)
+
+    def get_housekeeper_count(self, context, filters=None):
+        return len(self.housekeeper.list())
+
 
 # Register the callback
 def _validate_network_has_subnet(resource, event, trigger, **kwargs):
