@@ -20,6 +20,7 @@ from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
 from neutron_lib.callbacks import resources
 from neutron_lib import context as n_context
+from neutron_lib.db import utils as db_utils
 from neutron_lib.plugins import constants as plugin_constants
 from neutron_lib.plugins import directory
 from oslo_config import cfg
@@ -28,7 +29,6 @@ from oslo_utils import excutils
 from oslo_utils import uuidutils
 
 from neutron.db import _resource_extend as resource_extend
-from neutron.db import _utils as db_utils
 from neutron.db import agents_db
 from neutron.db import agentschedulers_db
 from neutron.db import allowedaddresspairs_db as addr_pair_db
@@ -126,6 +126,11 @@ class NsxTVDPlugin(agentschedulers_db.AZDhcpAgentSchedulerDbMixin,
         return True
 
     def _init_plugin(self, map_type, plugin_class):
+        if map_type not in cfg.CONF.nsx_tvd.enabled_plugins:
+            # skip this plugin
+            LOG.info("%s plugin was not enabled by the configuration",
+                     map_type.upper())
+            return
         try:
             self.plugins[map_type] = plugin_class()
         except Exception as e:
@@ -404,7 +409,9 @@ class NsxTVDPlugin(agentschedulers_db.AZDhcpAgentSchedulerDbMixin,
         # Read project plugin to filter relevant projects according to
         # plugin
         req_p = self._get_plugin_for_request(context, filters,
-                                             keys=['device_id'])
+                                             keys=['device_id',
+                                                   'network_id',
+                                                   'fixed_ips'])
         filters = filters or {}
         with db_api.context_manager.reader.using(context):
             ports = (
@@ -448,8 +455,8 @@ class NsxTVDPlugin(agentschedulers_db.AZDhcpAgentSchedulerDbMixin,
         # Check if we need to invoke metadata search. Here we are unable to
         # filter according to projects as this is from the nova api service
         # so we invoke on all plugins that support this extension
-        if ((fields and as_providers.ADV_SERVICE_PROVIDERS in fields)
-            or (filters and filters.get(as_providers.ADV_SERVICE_PROVIDERS))):
+        if ((fields and as_providers.ADV_SERVICE_PROVIDERS in fields) or
+            (filters and filters.get(as_providers.ADV_SERVICE_PROVIDERS))):
             for plugin in self.as_providers.values():
                 subnets = plugin.get_subnets(context, filters=filters,
                                              fields=fields, sorts=sorts,
@@ -634,7 +641,8 @@ class NsxTVDPlugin(agentschedulers_db.AZDhcpAgentSchedulerDbMixin,
                         page_reverse=False):
         # Read project plugin to filter relevant projects according to
         # plugin
-        req_p = self._get_plugin_for_request(context, filters)
+        req_p = self._get_plugin_for_request(context, filters,
+                                             keys=['port_id'])
         fips = super(NsxTVDPlugin, self).get_floatingips(
             context, filters=filters, fields=fields, sorts=sorts,
             limit=limit, marker=marker, page_reverse=page_reverse)
