@@ -14,8 +14,8 @@
 
 from oslo_log import log as logging
 
-from neutron.db import api as db_api
 from neutron_lib import constants as n_consts
+from neutron_lib.db import api as db_api
 from neutron_lib.plugins import constants as plugin_const
 
 from vmware_nsx._i18n import _
@@ -174,8 +174,8 @@ class RouterExclusiveDriver(router_driver.RouterBaseDriver):
 
         edge_id = self._get_router_edge_id(context, router_id)
         with locking.LockManager.get_lock(edge_id):
-            if ((new_ext_net_id != org_ext_net_id or force_update)
-                and orgnexthop):
+            if ((new_ext_net_id != org_ext_net_id or force_update) and
+                orgnexthop):
                 # network changed, so need to remove default gateway before
                 # vnic can be configured
                 LOG.debug("Delete default gateway %s", orgnexthop)
