@@ -15,12 +15,12 @@
 import netaddr
 from oslo_config import cfg
 
-from neutron.db import api as db_api
 from neutron.db import l3_db
 from neutron.db.models import l3 as l3_db_models
 from neutron.db import models_v2
 from neutron_lib.api import validators
 from neutron_lib import constants
+from neutron_lib.db import api as db_api
 from neutron_lib import exceptions as n_exc
 from oslo_log import log as logging
 
@@ -91,7 +91,7 @@ class RouterSharedDriver(router_driver.RouterBaseDriver):
 
     def detach_router(self, context, router_id, router):
         LOG.debug("Detach shared router id %s", router_id)
-        # if it is the last shared router on this adge - add it to the pool
+        # if it is the last shared router on this edge - add it to the pool
         edge_id = edge_utils.get_router_edge_id(context, router_id)
         if not edge_id:
             return
@@ -163,7 +163,7 @@ class RouterSharedDriver(router_driver.RouterBaseDriver):
         edge_utils.update_routes(self.nsx_v, context, target_router_id,
                                  all_routes, nexthop)
 
-    # return a dic of each router -> list of vnics from the other routers
+    # return a dict of each router -> list of vnics from the other routers
     def _get_all_routers_vnic_indices(self, context, router_ids):
 
         all_vnic_indices = {}
@@ -584,8 +584,8 @@ class RouterSharedDriver(router_driver.RouterBaseDriver):
         for router in routers:
             router_res = {}
             self.plugin._extend_nsx_router_dict(router_res, router)
-            if (router['id'] not in conflict_router_ids
-                and router_res.get('router_type') == 'shared'):
+            if (router['id'] not in conflict_router_ids and
+                router_res.get('router_type') == 'shared'):
                 optional_router_ids.append(router['id'])
         return optional_router_ids, conflict_router_ids
 
