@@ -13,9 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron_fwaas.common import fwaas_constants
 from neutron_lib.plugins import directory
 
+try:
+    from neutron_fwaas.common import fwaas_constants
+except ImportError:
+    # FWaaS project no found
+    from vmware_nsx.services.fwaas.common import fwaas_mocks \
+        as fwaas_constants
+
 
 def is_fwaas_v1_plugin_enabled():
     fwaas_plugin = directory.get_plugin(fwaas_constants.FIREWALL)
