@@ -19,8 +19,6 @@ from neutron_lib.plugins import directory
 from oslo_log import helpers as log_helpers
 from oslo_log import log as logging
 
-from neutron_fwaas.services.firewall.drivers import fwaas_base
-
 from vmware_nsx.common import locking
 from vmware_nsx.extensions import projectpluginmap
 from vmware_nsx.plugins.nsx_v.vshield import edge_utils
@@ -29,6 +27,14 @@ LOG = logging.getLogger(__name__)
 FWAAS_DRIVER_NAME = 'Fwaas V1 NSX-V driver'
 RULE_NAME_PREFIX = 'Fwaas-'
 
+try:
+    from neutron_fwaas.services.firewall.service_drivers.agents.drivers \
+        import fwaas_base
+except ImportError:
+    # FWaaS project no found
+    from vmware_nsx.services.fwaas.common import fwaas_mocks \
+        as fwaas_base
+
 
 class EdgeFwaasDriver(fwaas_base.FwaasDriverBase):
     """NSX-V driver for Firewall As A Service - V1."""
@@ -93,7 +99,7 @@ class EdgeFwaasDriver(fwaas_base.FwaasDriverBase):
 
         return True
 
-    def _get_routers_edges(self, context, apply_list):
+    def _get_routers_edges(self, context, apply_list, delete_fw=False):
         # Get edges for all the routers in the apply list.
         # note that shared routers are currently not supported
         edge_manager = self.edge_manager
@@ -101,7 +107,8 @@ class EdgeFwaasDriver(fwaas_base.FwaasDriverBase):
         for router_info in apply_list:
 
             # No FWaaS rules needed if there is no external gateway
-            if not self.should_apply_firewall_to_router(router_info.router):
+            if not self.should_apply_firewall_to_router(
+                router_info.router, raise_exception=(not delete_fw)):
                 continue
 
             lookup_id = None
@@ -218,7 +225,8 @@ class EdgeFwaasDriver(fwaas_base.FwaasDriverBase):
                                                delete_fw=False):
         # get router-edge mapping
         context = n_context.get_admin_context()
-        edges_map = self._get_routers_edges(context, apply_list)
+        edges_map = self._get_routers_edges(context, apply_list,
+                                            delete_fw=delete_fw)
 
         # if the firewall is deleted, rules should be None
         rules = None if delete_fw else []
