@@ -38,7 +38,6 @@ from vmware_nsxlib.v3 import vpn_ipsec
 
 LOG = logging.getLogger(__name__)
 IPSEC = 'ipsec'
-VPN_PORT_OWNER = constants.DEVICE_OWNER_NEUTRON_PREFIX + 'vpnservice'
 
 
 class RouterWithSNAT(nexception.BadRequest):
@@ -46,6 +45,16 @@ class RouterWithSNAT(nexception.BadRequest):
                 "SNAT")
 
 
+class RouterWithOverlapNoSnat(nexception.BadRequest):
+    message = _("Router %(router_id)s has a subnet overlapping with a VPN "
+                "local subnet, and cannot disable SNAT")
+
+
+class RouterOverlapping(nexception.BadRequest):
+    message = _("Router %(router_id)s interface is overlapping with a VPN "
+                "local subnet and cannot be added")
+
+
 class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
 
     def __init__(self, service_plugin):
@@ -63,6 +72,10 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
             self._delete_local_endpoint, resources.ROUTER_GATEWAY,
             events.AFTER_DELETE)
 
+        registry.subscribe(
+            self._verify_overlap_subnet, resources.ROUTER_INTERFACE,
+            events.BEFORE_CREATE)
+
     @property
     def l3_plugin(self):
         return self._core_plugin
@@ -104,9 +117,9 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
                 fw_rules.append({
                     'display_name': 'VPN connection ' + conn['id'],
                     'action': consts.FW_ACTION_ALLOW,
-                    'sources': self._translate_addresses_to_target(
-                        peer_cidrs),
                     'destinations': self._translate_addresses_to_target(
+                        peer_cidrs),
+                    'sources': self._translate_addresses_to_target(
                         local_cidrs)})
 
         return fw_rules
@@ -186,7 +199,7 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
         ikepolicy = self.vpn_plugin.get_ikepolicy(context, ike_policy_id)
         try:
             profile = self._nsx_vpn.ike_profile.create(
-                ikepolicy['name'],
+                ikepolicy['name'] or ikepolicy['id'],
                 description=ikepolicy['description'],
                 encryption_algorithm=ipsec_utils.ENCRYPTION_ALGORITHM_MAP[
                     ikepolicy['encryption_algorithm']],
@@ -217,7 +230,7 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
 
         try:
             profile = self._nsx_vpn.tunnel_profile.create(
-                ipsecpolicy['name'],
+                ipsecpolicy['name'] or ipsecpolicy['id'],
                 description=ipsecpolicy['description'],
                 encryption_algorithm=ipsec_utils.ENCRYPTION_ALGORITHM_MAP[
                     ipsecpolicy['encryption_algorithm']],
@@ -235,11 +248,14 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
     def _delete_ipsec_profile(self, ipsecprofile_id):
         self._nsx_vpn.tunnel_profile.delete(ipsecprofile_id)
 
+    def _get_dpd_profile_name(self, connection):
+        return (connection['name'] or connection['id'])[:240] + '-dpd-profile'
+
     def _create_dpd_profile(self, context, connection):
         dpd_info = connection['dpd']
         try:
             profile = self._nsx_vpn.dpd_profile.create(
-                connection['name'][:240] + '-dpd-profile',
+                self._get_dpd_profile_name(connection),
                 description='neutron dpd profile',
                 timeout=dpd_info.get('timeout'),
                 enabled=True if dpd_info.get('action') == 'hold' else False,
@@ -256,6 +272,7 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
     def _update_dpd_profile(self, connection, dpdprofile_id):
         dpd_info = connection['dpd']
         self._nsx_vpn.dpd_profile.update(dpdprofile_id,
+                name=self._get_dpd_profile_name(connection),
                 timeout=dpd_info.get('timeout'),
                 enabled=True if dpd_info.get('action') == 'hold' else False)
 
@@ -264,7 +281,7 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
         default_auth = vpn_ipsec.AuthenticationModeTypes.AUTH_MODE_PSK
         try:
             peer_endpoint = self._nsx_vpn.peer_endpoint.create(
-                connection['name'],
+                connection['name'] or connection['id'],
                 connection['peer_address'],
                 connection['peer_id'],
                 description=connection['description'],
@@ -285,7 +302,7 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
     def _update_peer_endpoint(self, peer_ep_id, connection):
         self._nsx_vpn.peer_endpoint.update(
             peer_ep_id,
-            name=connection['name'],
+            name=connection['name'] or connection['id'],
             peer_address=connection['peer_address'],
             peer_id=connection['peer_id'],
             description=connection['description'],
@@ -304,7 +321,7 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
             peer_ep['dpd_profile_id'])
 
     def _create_local_endpoint(self, context, local_addr, nsx_service_id,
-                               router_id):
+                               router_id, project_id):
         """Creating an NSX local endpoint for a logical router
 
         This endpoint can be reused by other connections, and will be deleted
@@ -312,7 +329,8 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
         """
         # Add the neutron router-id to the tags to help search later
         tags = self._nsxlib.build_v3_tags_payload(
-            {'id': router_id}, resource_type='os-neutron-router-id',
+            {'id': router_id, 'project_id': project_id},
+            resource_type='os-neutron-router-id',
             project_name=context.tenant_name)
 
         try:
@@ -353,13 +371,14 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
         local_addr = vpnservice['external_v4_ip']
         nsx_service_id = self._get_nsx_vpn_service(context, vpnservice)
         local_ep_id = self._create_local_endpoint(
-            context, local_addr, nsx_service_id, router_id)
+            context, local_addr, nsx_service_id, router_id,
+            vpnservice['project_id'])
         return local_ep_id
 
     def _find_vpn_service_port(self, context, router_id):
         """Look for the neutron port created for the vpnservice of a router"""
-        filters = {'device_id': [router_id],
-                   'device_owner': [VPN_PORT_OWNER]}
+        filters = {'device_id': ['router-' + router_id],
+                   'device_owner': [ipsec_utils.VPN_PORT_OWNER]}
         ports = self.l3_plugin.get_ports(context, filters=filters)
         if ports:
             return ports[0]
@@ -375,20 +394,73 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
         ctx = n_context.get_admin_context()
         port = self._find_vpn_service_port(ctx, router_id)
         if port:
-            self.l3_plugin.delete_port(ctx, port['id'])
+            self.l3_plugin.delete_port(ctx, port['id'], force_delete_vpn=True)
+
+    def _check_subnets_overlap_with_all_conns(self, context, subnets):
+        # find all vpn services with connections
+        filters = {'status': [constants.ACTIVE]}
+        connections = self.vpn_plugin.get_ipsec_site_connections(
+            context, filters=filters)
+        for conn in connections:
+            srv_id = conn.get('vpnservice_id')
+            srv = self.vpn_plugin._get_vpnservice(context, srv_id)
+            srv_subnet = self.l3_plugin.get_subnet(
+                context, srv['subnet_id'])
+            if netaddr.IPSet(subnets) & netaddr.IPSet([srv_subnet['cidr']]):
+                return False
+
+        return True
+
+    def _verify_overlap_subnet(self, resource, event, trigger, **kwargs):
+        """Upon router interface creation validation overlapping with vpn"""
+        router_db = kwargs.get('router_db')
+        port = kwargs.get('port')
+        if not port or not router_db:
+            LOG.warning("NSX V3 VPNaaS ROUTER_INTERFACE BEFORE_CRAETE "
+                        "callback didn't get all the relevant information")
+            return
+
+        if router_db.enable_snat:
+            # checking only no-snat routers
+            return
+
+        admin_con = n_context.get_admin_context()
+        subnet_id = port['fixed_ips'][0].get('subnet_id')
+        if subnet_id:
+            subnet = self._core_plugin.get_subnet(admin_con, subnet_id)
+            # find all vpn services with connections
+            if not self._check_subnets_overlap_with_all_conns(
+                admin_con, [subnet['cidr']]):
+                raise RouterOverlapping(router_id=kwargs.get('router_id'))
 
     def validate_router_gw_info(self, context, router_id, gw_info):
         """Upon router gw update - verify no-snat"""
-        # ckeck if this router has a vpn service
+        # check if this router has a vpn service
+        admin_con = context.elevated()
+        # get all relevant services, except those waiting to be deleted or in
+        # ERROR state
         filters = {'router_id': [router_id],
-                   'status': [constants.ACTIVE]}
-        services = self.vpn_plugin.get_vpnservices(
-            context.elevated(), filters=filters)
+                   'status': [constants.ACTIVE, constants.PENDING_CREATE,
+                              constants.INACTIVE, constants.PENDING_UPDATE]}
+        services = self.vpn_plugin.get_vpnservices(admin_con, filters=filters)
         if services:
             # do not allow enable-snat
             if (gw_info and
                 gw_info.get('enable_snat', cfg.CONF.enable_snat_by_default)):
                 raise RouterWithSNAT(router_id=router_id)
+        else:
+            # if this is a non-vpn router. if snat was disabled, should check
+            # there is no overlapping with vpn connections
+            if (gw_info and
+                not gw_info.get('enable_snat',
+                                cfg.CONF.enable_snat_by_default)):
+                # get router subnets
+                subnets = self._core_plugin._find_router_subnets_cidrs(
+                    context, router_id)
+                # find all vpn services with connections
+                if not self._check_subnets_overlap_with_all_conns(
+                    admin_con, subnets):
+                    raise RouterWithOverlapNoSnat(router_id=router_id)
 
     def _get_session_rules(self, context, connection, vpnservice):
         # TODO(asarfaty): support vpn-endpoint-groups too
@@ -398,24 +470,28 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
         return [rule]
 
     def _create_session(self, context, connection, local_ep_id,
-                        peer_ep_id, rules):
+                        peer_ep_id, rules, enabled=True):
         try:
             session = self._nsx_vpn.session.create(
-                connection['name'], local_ep_id, peer_ep_id, rules,
+                connection['name'] or connection['id'],
+                local_ep_id, peer_ep_id, rules,
                 description=connection['description'],
-                tags=self._nsx_tags(context, connection))
+                tags=self._nsx_tags(context, connection),
+                enabled=enabled)
         except nsx_lib_exc.ManagerError as e:
             msg = _("Failed to create a session: %s") % e
             raise nsx_exc.NsxPluginException(err_msg=msg)
 
         return session['id']
 
-    def _update_session(self, session_id, connection, rules):
+    def _update_session(self, session_id, connection, rules=None,
+                        enabled=True):
         self._nsx_vpn.session.update(
             session_id,
-            name=connection['name'],
+            name=connection['name'] or connection['id'],
             description=connection['description'],
-            policy_rules=rules)
+            policy_rules=rules,
+            enabled=enabled)
 
     def _delete_session(self, session_id):
         self._nsx_vpn.session.delete(session_id)
@@ -465,8 +541,11 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
             # Finally: create the session with policy rules
             rules = self._get_session_rules(
                 context, ipsec_site_conn, vpnservice)
+            connection_enabled = (vpnservice['admin_state_up'] and
+                                  ipsec_site_conn['admin_state_up'])
             session_id = self._create_session(
-                context, ipsec_site_conn, local_ep_id, peer_ep_id, rules)
+                context, ipsec_site_conn, local_ep_id, peer_ep_id, rules,
+                enabled=connection_enabled)
 
             # update the DB with the session id
             db.add_nsx_vpn_connection_mapping(
@@ -559,15 +638,12 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
             self._update_status(context, vpnservice_id, ipsec_id, "ERROR")
             raise nsx_exc.NsxIPsecVpnMappingNotFound(conn=ipsec_id)
 
-        update_all = (old_ipsec_conn['name'] != ipsec_site_conn['name'] or
-                      old_ipsec_conn['description'] !=
-                      ipsec_site_conn['description'])
         # check if the dpd configuration changed
         old_dpd = old_ipsec_conn['dpd']
         new_dpd = ipsec_site_conn['dpd']
         if (old_dpd['action'] != new_dpd['action'] or
             old_dpd['timeout'] != new_dpd['timeout'] or
-            update_all):
+            old_ipsec_conn['name'] != ipsec_site_conn['name']):
             self._update_dpd_profile(ipsec_site_conn,
                                      mapping['dpd_profile_id'])
 
@@ -576,9 +652,12 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
         self._update_peer_endpoint(mapping['peer_ep_id'], ipsec_site_conn)
         rules = self._get_session_rules(
             context, ipsec_site_conn, vpnservice)
-        self._update_session(mapping['session_id'], ipsec_site_conn, rules)
+        connection_enabled = (vpnservice['admin_state_up'] and
+                              ipsec_site_conn['admin_state_up'])
+        self._update_session(mapping['session_id'], ipsec_site_conn, rules,
+                             enabled=connection_enabled)
 
-        if 'peer_cidrs' in ipsec_site_conn:
+        if ipsec_site_conn['peer_cidrs'] != old_ipsec_conn['peer_cidrs']:
             # Update firewall
             self._update_firewall_rules(context, vpnservice)
 
@@ -587,7 +666,7 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
     def _create_vpn_service(self, tier0_uuid):
         try:
             service = self._nsx_vpn.service.create(
-                'Neutron VPN service for router ' + tier0_uuid,
+                'Neutron VPN service for T0 router ' + tier0_uuid,
                 tier0_uuid,
                 enabled=True,
                 ike_log_level=ipsec_utils.DEFAULT_LOG_LEVEL,
@@ -645,14 +724,16 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
         port = self._find_vpn_service_port(context, router_id)
         if not port:
             # create a new port, on the external network of the router
+            # Note(asarfaty): using a unique device owner and device id to
+            # make sure tis port will be ignored in certain queries
             ext_net = vpnservice.router.gw_port['network_id']
             port_data = {
                 'port': {
                     'network_id': ext_net,
-                    'name': None,
+                    'name': 'VPN local address port',
                     'admin_state_up': True,
-                    'device_id': vpnservice.router['id'],
-                    'device_owner': VPN_PORT_OWNER,
+                    'device_id': 'router-' + vpnservice.router['id'],
+                    'device_owner': ipsec_utils.VPN_PORT_OWNER,
                     'fixed_ips': constants.ATTR_NOT_SPECIFIED,
                     'mac_address': constants.ATTR_NOT_SPECIFIED,
                     'port_security_enabled': False,
@@ -671,7 +752,7 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
         try:
             self.validator.validate_vpnservice(context, vpnservice)
             local_address = self._get_service_local_address(
-                context, vpnservice)
+                context.elevated(), vpnservice)
         except Exception:
             with excutils.save_and_reraise_exception():
                 # Rolling back change on the neutron
@@ -684,8 +765,20 @@ class NSXv3IPsecVpnDriver(service_drivers.VpnDriver):
         self._create_vpn_service_if_needed(context, vpnservice)
 
     def update_vpnservice(self, context, old_vpnservice, vpnservice):
-        # No meaningful field can change here
-        pass
+        # Only handle the case of admin-state-up changes
+        if old_vpnservice['admin_state_up'] != vpnservice['admin_state_up']:
+            # update all relevant connections
+            filters = {'vpnservice_id': [vpnservice['id']]}
+            connections = self.vpn_plugin.get_ipsec_site_connections(
+                context, filters=filters)
+            for conn in connections:
+                mapping = db.get_nsx_vpn_connection_mapping(
+                    context.session, conn['id'])
+                if mapping:
+                    connection_enabled = (vpnservice['admin_state_up'] and
+                                          conn['admin_state_up'])
+                    self._update_session(mapping['session_id'], conn,
+                                         enabled=connection_enabled)
 
     def delete_vpnservice(self, context, vpnservice):
         # Do not delete the NSX service or DB entry as those will be reused.
