@@ -45,6 +45,8 @@ LB_VIRTUAL_SERVERS = 'lb-virtual-servers'
 LB_POOLS = 'lb-pools'
 LB_MONITORS = 'lb-monitors'
 RATE_LIMIT = 'rate-limit'
+CLUSTER = 'cluster'
+ORPHANED_FIREWALL_SECTIONS = 'orphaned-firewall-sections'
 
 # NSXV only Resource Constants
 EDGES = 'edges'
@@ -60,6 +62,7 @@ LBAAS = 'lbaas'
 BGP_GW_EDGE = 'bgp-gw-edge'
 ROUTING_REDIS_RULE = 'routing-redistribution-rule'
 BGP_NEIGHBOUR = 'bgp-neighbour'
+NSX_PORTGROUPS = 'nsx-portgroups'
 
 # NSXTV only Resource Constants
 PROJECTS = 'projects'
