@@ -12,7 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
+import re
 import xml.etree.ElementTree as et
 
 from neutron.db import api as db_api
@@ -31,6 +31,7 @@ from vmware_nsx.db import extended_security_group_rule as extend_sg_rule
 from vmware_nsx.db import nsx_models
 from vmware_nsx.db import nsxv_db
 from vmware_nsx.db import nsxv_models
+from vmware_nsx.extensions import securitygrouplogging as sg_logging
 from vmware_nsx.extensions import securitygrouppolicy as sg_policy
 from vmware_nsx.shell.admin.plugins.common import constants
 from vmware_nsx.shell.admin.plugins.common import formatters
@@ -158,6 +159,11 @@ class NsxFirewallAPI(object):
                              'id': sec_id})
         return sections
 
+    def delete_fw_section(self, section_id):
+        section_uri = ("/api/4.0/firewall/globalroot-0/"
+                       "config/layer3sections/%s" % section_id)
+        self.vcns.delete_section(section_uri)
+
     def reorder_fw_sections(self):
         # read all the sections
         h, firewall_config = self.vcns.get_dfw_config()
@@ -294,7 +300,38 @@ def list_missing_firewall_sections(resource, event, trigger, **kwargs):
     return bool(missing_sections_info)
 
 
-@admin_utils.list_mismatches_handler(constants.FIREWALL_SECTIONS)
+def _get_unused_firewall_sections():
+    fw_sections = nsxv_firewall.list_fw_sections()
+    sg_mappings = neutron_sg.get_security_groups_mappings()
+    unused_sections = []
+    for fw_section in fw_sections:
+        for sg_db in sg_mappings:
+            if fw_section['id'] == sg_db.get('section-uri', '').split('/')[-1]:
+                break
+        else:
+            # skip sections with non neutron like names
+            if re.search("SG Section: .* (.*)", fw_section['name']):
+                unused_sections.append(fw_section)
+    return unused_sections
+
+
+@admin_utils.output_header
+def list_unused_firewall_sections(resource, event, trigger, **kwargs):
+    unused_sections = _get_unused_firewall_sections()
+    _log_info(constants.FIREWALL_SECTIONS, unused_sections,
+              attrs=['name', 'id'])
+    return bool(unused_sections)
+
+
+@admin_utils.output_header
+def clean_unused_firewall_sections(resource, event, trigger, **kwargs):
+    unused_sections = _get_unused_firewall_sections()
+    for fw_section in unused_sections:
+        LOG.info("Deleting firewall section %s", fw_section['id'])
+        nsxv_firewall.delete_fw_section(fw_section['id'])
+    return bool(unused_sections)
+
+
 @admin_utils.output_header
 def reorder_firewall_sections(resource, event, trigger, **kwargs):
     nsxv_firewall.reorder_fw_sections()
@@ -319,6 +356,7 @@ def fix_security_groups(resource, event, trigger, **kwargs):
             plugin._create_fw_section_for_security_group(
                 context_, secgroup,
                 sgs_with_missing_section[sg_id]['nsx-securitygroup-id'])
+            LOG.info("Created NSX section for security group %s", sg_id)
 
         # If nsx security-group is missing then create both nsx security-group
         # and a new fw section (remove old one).
@@ -330,6 +368,8 @@ def fix_security_groups(resource, event, trigger, **kwargs):
             neutron_sg.delete_security_group_backend_mapping(sg_id)
             plugin._process_security_group_create_backend_resources(context_,
                                                                     secgroup)
+            LOG.info("Created NSX section & security group for security group"
+                     " %s", sg_id)
             nsx_id = nsx_db.get_nsx_security_group_id(context_.session, sg_id,
                                                       moref=False)
             for vnic_id in neutron_sg.get_vnics_in_security_group(sg_id):
@@ -425,6 +465,63 @@ def firewall_update_cluster_default_fw_section(resource, event, trigger,
         LOG.info("Cluster default FW section updated.")
 
 
+@admin_utils.output_header
+def update_security_groups_logging(resource, event, trigger, **kwargs):
+    """Update allowed traffic logging for all neutron security group rules"""
+    errmsg = ("Need to specify log-allowed-traffic property. Add --property "
+              "log-allowed-traffic=true/false")
+    if not kwargs.get('property'):
+        LOG.error("%s", errmsg)
+        return
+    properties = admin_utils.parse_multi_keyval_opt(kwargs['property'])
+    log_allowed_str = properties.get('log-allowed-traffic')
+    if not log_allowed_str or log_allowed_str.lower() not in ['true', 'false']:
+        LOG.error("%s", errmsg)
+        return
+    log_allowed = log_allowed_str.lower() == 'true'
+
+    context = n_context.get_admin_context()
+
+    with utils.NsxVPluginWrapper() as plugin:
+        vcns = plugin.nsx_v.vcns
+        sg_utils = plugin. nsx_sg_utils
+        # If the section/sg is already logged, then no action is
+        # required.
+        security_groups = plugin.get_security_groups(context)
+        LOG.info("Going to update logging of %s sections",
+                 len(security_groups))
+        for sg in [sg for sg in plugin.get_security_groups(context)
+                   if sg.get(sg_logging.LOGGING) is False]:
+            if sg.get(sg_policy.POLICY):
+                # Logging is not relevant with a policy
+                continue
+
+            section_uri = plugin._get_section_uri(context.session,
+                                                  sg['id'])
+            if section_uri is None:
+                continue
+
+            # Section/sg is not logged, update rules logging according
+            # to the 'log_security_groups_allowed_traffic' config
+            # option.
+            try:
+                h, c = vcns.get_section(section_uri)
+                section = sg_utils.parse_section(c)
+                section_needs_update = sg_utils.set_rules_logged_option(
+                    section, log_allowed)
+                if section_needs_update:
+                    vcns.update_section(section_uri,
+                                        sg_utils.to_xml_string(section), h)
+            except Exception as exc:
+                LOG.error('Unable to update security group %(sg)s '
+                          'section for logging. %(e)s',
+                          {'e': exc, 'sg': sg['id']})
+
+
+registry.subscribe(update_security_groups_logging,
+                   constants.SECURITY_GROUPS,
+                   shell.Operations.UPDATE_LOGGING.value)
+
 registry.subscribe(migrate_sg_to_policy,
                    constants.SECURITY_GROUPS,
                    shell.Operations.MIGRATE_TO_POLICY.value)
@@ -440,3 +537,11 @@ registry.subscribe(fix_security_groups,
 registry.subscribe(firewall_update_cluster_default_fw_section,
                    constants.FIREWALL_SECTIONS,
                    shell.Operations.NSX_UPDATE.value)
+
+registry.subscribe(list_unused_firewall_sections,
+                   constants.FIREWALL_SECTIONS,
+                   shell.Operations.LIST_UNUSED.value)
+
+registry.subscribe(clean_unused_firewall_sections,
+                   constants.FIREWALL_SECTIONS,
+                   shell.Operations.NSX_CLEAN.value)
