@@ -14,7 +14,6 @@
 
 from neutron.db import api as db_api
 from neutron.db import common_db_mixin as common_db
-from neutron.db.models import securitygroup
 from neutron.db import securitygroups_db
 from neutron_lib.callbacks import registry
 from neutron_lib import context as neutron_context
@@ -24,12 +23,13 @@ from vmware_nsx.db import db as nsx_db
 from vmware_nsx.db import nsx_models
 from vmware_nsx.extensions import providersecuritygroup as provider_sg
 from vmware_nsx.extensions import securitygrouplogging as sg_logging
+from vmware_nsx.plugins.nsx_v3 import utils as plugin_utils
 from vmware_nsx.shell.admin.plugins.common import constants
 from vmware_nsx.shell.admin.plugins.common import formatters
 from vmware_nsx.shell.admin.plugins.common import utils as admin_utils
-from vmware_nsx.shell.admin.plugins.nsxv3.resources import ports
 from vmware_nsx.shell.admin.plugins.nsxv3.resources import utils as v3_utils
 from vmware_nsx.shell import resources as shell
+from vmware_nsxlib.v3 import exceptions as nsx_lib_exc
 from vmware_nsxlib.v3 import nsx_constants as consts
 from vmware_nsxlib.v3 import security
 
@@ -82,21 +82,6 @@ class NeutronSecurityGroupApi(securitygroups_db.SecurityGroupDbMixin,
             if sg_mapping:
                 self.context.session.delete(sg_mapping)
 
-    def get_security_groups_mappings(self):
-        q = self.context.session.query(
-            securitygroup.SecurityGroup.name,
-            securitygroup.SecurityGroup.id,
-            nsx_models.NeutronNsxFirewallSectionMapping.nsx_id,
-            nsx_models.NeutronNsxSecurityGroupMapping.nsx_id).join(
-                nsx_models.NeutronNsxFirewallSectionMapping,
-                nsx_models.NeutronNsxSecurityGroupMapping).all()
-        sg_mappings = [{'name': mapp[0],
-                        'id': mapp[1],
-                        'section-id': mapp[2],
-                        'nsx-securitygroup-id': mapp[3]}
-                       for mapp in q]
-        return sg_mappings
-
     def get_logical_port_id(self, port_id):
         mapping = self.context.session.query(
             nsx_models.NeutronNsxPortMapping).filter_by(
@@ -116,7 +101,8 @@ def _log_info(resource, data, attrs=['display_name', 'id']):
 @admin_utils.list_handler(constants.SECURITY_GROUPS)
 @admin_utils.output_header
 def list_security_groups_mappings(resource, event, trigger, **kwargs):
-    sg_mappings = neutron_sg.get_security_groups_mappings()
+    """List neutron security groups"""
+    sg_mappings = plugin_utils.get_security_groups_mappings(neutron_sg.context)
     _log_info(constants.SECURITY_GROUPS,
               sg_mappings,
               attrs=['name', 'id', 'section-id', 'nsx-securitygroup-id'])
@@ -126,6 +112,7 @@ def list_security_groups_mappings(resource, event, trigger, **kwargs):
 @admin_utils.list_handler(constants.FIREWALL_SECTIONS)
 @admin_utils.output_header
 def nsx_list_dfw_sections(resource, event, trigger, **kwargs):
+    """List NSX backend firewall sections"""
     nsxlib = v3_utils.get_connected_nsxlib()
     fw_sections = nsxlib.firewall_section.list()
     _log_info(constants.FIREWALL_SECTIONS, fw_sections)
@@ -135,6 +122,7 @@ def nsx_list_dfw_sections(resource, event, trigger, **kwargs):
 @admin_utils.list_handler(constants.FIREWALL_NSX_GROUPS)
 @admin_utils.output_header
 def nsx_list_security_groups(resource, event, trigger, **kwargs):
+    """List NSX backend security groups"""
     nsxlib = v3_utils.get_connected_nsxlib()
     nsx_secgroups = nsxlib.ns_group.list()
     _log_info(constants.FIREWALL_NSX_GROUPS, nsx_secgroups)
@@ -144,7 +132,7 @@ def nsx_list_security_groups(resource, event, trigger, **kwargs):
 def _find_missing_security_groups():
     nsxlib = v3_utils.get_connected_nsxlib()
     nsx_secgroups = nsxlib.ns_group.list()
-    sg_mappings = neutron_sg.get_security_groups_mappings()
+    sg_mappings = plugin_utils.get_security_groups_mappings(neutron_sg.context)
     missing_secgroups = {}
     for sg_db in sg_mappings:
         for nsx_sg in nsx_secgroups:
@@ -158,6 +146,7 @@ def _find_missing_security_groups():
 @admin_utils.list_mismatches_handler(constants.FIREWALL_NSX_GROUPS)
 @admin_utils.output_header
 def list_missing_security_groups(resource, event, trigger, **kwargs):
+    """List security groups with sections missing on the NSX backend"""
     sgs_with_missing_nsx_group = _find_missing_security_groups()
     missing_securitgroups_info = [
         {'securitygroup-name': sg['name'],
@@ -174,7 +163,7 @@ def list_missing_security_groups(resource, event, trigger, **kwargs):
 def _find_missing_sections():
     nsxlib = v3_utils.get_connected_nsxlib()
     fw_sections = nsxlib.firewall_section.list()
-    sg_mappings = neutron_sg.get_security_groups_mappings()
+    sg_mappings = plugin_utils.get_security_groups_mappings(neutron_sg.context)
     missing_sections = {}
     for sg_db in sg_mappings:
         for fw_section in fw_sections:
@@ -188,6 +177,7 @@ def _find_missing_sections():
 @admin_utils.list_mismatches_handler(constants.FIREWALL_SECTIONS)
 @admin_utils.output_header
 def list_missing_firewall_sections(resource, event, trigger, **kwargs):
+    """List security groups with missing sections on the NSX backend"""
     sgs_with_missing_section = _find_missing_sections()
     missing_sections_info = [{'securitygroup-name': sg['name'],
                               'securitygroup-id': sg['id'],
@@ -201,6 +191,9 @@ def list_missing_firewall_sections(resource, event, trigger, **kwargs):
 @admin_utils.fix_mismatches_handler(constants.SECURITY_GROUPS)
 @admin_utils.output_header
 def fix_security_groups(resource, event, trigger, **kwargs):
+    """Fix mismatch security groups by recreating missing sections & NS groups
+    on the NSX backend
+    """
     context_ = neutron_context.get_admin_context()
     inconsistent_secgroups = _find_missing_sections()
     inconsistent_secgroups.update(_find_missing_security_groups())
@@ -252,7 +245,6 @@ def fix_security_groups(resource, event, trigger, **kwargs):
 
 def _update_ports_dynamic_criteria_tags():
     nsxlib = v3_utils.get_connected_nsxlib()
-    port_client, _ = ports.get_port_and_profile_clients()
     for port in neutron_db.get_ports():
         secgroups = neutron_sg.get_port_security_groups(port['id'])
         # Nothing to do with ports that are not associated with any sec-group.
@@ -261,7 +253,8 @@ def _update_ports_dynamic_criteria_tags():
 
         _, lport_id = neutron_db.get_lswitch_and_lport_id(port['id'])
         criteria_tags = nsxlib.ns_group.get_lport_tags(secgroups)
-        port_client.update(lport_id, False, tags_update=criteria_tags)
+        nsxlib.logical_port.update(
+            lport_id, False, tags_update=criteria_tags)
 
 
 def _update_security_group_dynamic_criteria():
@@ -286,6 +279,7 @@ def _update_security_group_dynamic_criteria():
 
 @admin_utils.output_header
 def migrate_nsgroups_to_dynamic_criteria(resource, event, trigger, **kwargs):
+    """Update NSX security groups dynamic criteria for NSXv3 CrossHairs"""
     nsxlib = v3_utils.get_connected_nsxlib()
     if not nsxlib.feature_supported(consts.FEATURE_DYNAMIC_CRITERIA):
         LOG.error("Dynamic criteria grouping feature isn't supported by "
@@ -297,6 +291,70 @@ def migrate_nsgroups_to_dynamic_criteria(resource, event, trigger, **kwargs):
     _update_security_group_dynamic_criteria()
 
 
+def list_orphaned_sections(resource, event, trigger, **kwargs):
+    """List orphaned firewall sections"""
+    nsxlib = v3_utils.get_connected_nsxlib()
+    orphaned_sections = plugin_utils.get_orphaned_firewall_sections(
+        neutron_sg.context, nsxlib)
+    _log_info(constants.ORPHANED_FIREWALL_SECTIONS, orphaned_sections,
+              attrs=['id', 'display_name'])
+
+
+def clean_orphaned_sections(resource, event, trigger, **kwargs):
+    """Delete orphaned firewall sections from the NSX backend"""
+    nsxlib = v3_utils.get_connected_nsxlib()
+    orphaned_sections = plugin_utils.get_orphaned_firewall_sections(
+        neutron_sg.context, nsxlib)
+    for sec in orphaned_sections:
+        try:
+            nsxlib.firewall_section.delete(sec['id'])
+        except Exception as e:
+            LOG.error("Failed to delete backend firewall section %(id)s : "
+                      "%(e)s.", {'id': sec['id'], 'e': e})
+        else:
+            LOG.info("Backend firewall section %s was deleted.", sec['id'])
+
+
+def update_security_groups_logging(resource, event, trigger, **kwargs):
+    """Update allowed traffic logging for all neutron security group rules"""
+    errmsg = ("Need to specify log-allowed-traffic property. Add --property "
+              "log-allowed-traffic=true/false")
+    if not kwargs.get('property'):
+        LOG.error("%s", errmsg)
+        return
+    properties = admin_utils.parse_multi_keyval_opt(kwargs['property'])
+    log_allowed_str = properties.get('log-allowed-traffic')
+    if not log_allowed_str or log_allowed_str.lower() not in ['true', 'false']:
+        LOG.error("%s", errmsg)
+        return
+    log_allowed = log_allowed_str.lower() == 'true'
+
+    context = neutron_context.get_admin_context()
+    nsxlib = v3_utils.get_connected_nsxlib()
+
+    with v3_utils.NsxV3PluginWrapper() as plugin:
+        secgroups = plugin.get_security_groups(context,
+                                             fields=['id',
+                                             sg_logging.LOGGING])
+        LOG.info("Going to update logging of %s sections",
+                 len(secgroups))
+        for sg in [sg for sg in secgroups
+                   if sg.get(sg_logging.LOGGING) is False]:
+            nsgroup_id, section_id = nsx_db.get_sg_mappings(
+                context.session, sg['id'])
+            if section_id:
+                try:
+                    nsxlib.firewall_section.set_rule_logging(
+                        section_id, logging=log_allowed)
+                except nsx_lib_exc.ManagerError:
+                    LOG.error("Failed to update firewall rule logging "
+                              "for rule in section %s", section_id)
+
+
+registry.subscribe(update_security_groups_logging,
+                   constants.SECURITY_GROUPS,
+                   shell.Operations.UPDATE_LOGGING.value)
+
 registry.subscribe(migrate_nsgroups_to_dynamic_criteria,
                    constants.FIREWALL_NSX_GROUPS,
                    shell.Operations.MIGRATE_TO_DYNAMIC_CRITERIA.value)
@@ -304,3 +362,11 @@ registry.subscribe(migrate_nsgroups_to_dynamic_criteria,
 registry.subscribe(fix_security_groups,
                    constants.FIREWALL_SECTIONS,
                    shell.Operations.NSX_UPDATE.value)
+
+registry.subscribe(list_orphaned_sections,
+                   constants.ORPHANED_FIREWALL_SECTIONS,
+                   shell.Operations.NSX_LIST.value)
+
+registry.subscribe(clean_orphaned_sections,
+                   constants.ORPHANED_FIREWALL_SECTIONS,
+                   shell.Operations.NSX_CLEAN.value)
