@@ -38,6 +38,7 @@ class Operations(enum.Enum):
     DELETE = 'delete'
     LIST_MISMATCHES = 'list-mismatches'
     FIX_MISMATCH = 'fix-mismatch'
+    LIST_UNUSED = 'list-unused'
 
     NEUTRON_LIST = 'neutron-list'
     NEUTRON_CLEAN = 'neutron-clean'
@@ -58,6 +59,7 @@ class Operations(enum.Enum):
     MIGRATE_TO_DYNAMIC_CRITERIA = 'migrate-to-dynamic-criteria'
     NSX_MIGRATE_V_V3 = 'nsx-migrate-v-v3'
     MIGRATE_TO_POLICY = 'migrate-to-policy'
+    UPDATE_LOGGING = 'update-logging'
     NSX_MIGRATE_EXCLUDE_PORTS = 'migrate-exclude-ports'
     MIGRATE_VDR_DHCP = 'migrate-vdr-dhcp'
     STATUS = 'status'
@@ -79,7 +81,8 @@ class Resource(object):
 nsxv3_resources = {
     constants.SECURITY_GROUPS: Resource(constants.SECURITY_GROUPS,
                                         [Operations.LIST.value,
-                                         Operations.FIX_MISMATCH.value]),
+                                         Operations.FIX_MISMATCH.value,
+                                         Operations.UPDATE_LOGGING.value]),
     constants.FIREWALL_SECTIONS: Resource(constants.FIREWALL_SECTIONS,
                                           [Operations.LIST.value,
                                            Operations.LIST_MISMATCHES.value]),
@@ -88,6 +91,10 @@ nsxv3_resources = {
             Operations.LIST.value,
             Operations.LIST_MISMATCHES.value,
             Operations.MIGRATE_TO_DYNAMIC_CRITERIA.value]),
+    constants.ORPHANED_FIREWALL_SECTIONS: Resource(
+        constants.ORPHANED_FIREWALL_SECTIONS, [
+            Operations.NSX_LIST.value,
+            Operations.NSX_CLEAN.value]),
     constants.NETWORKS: Resource(constants.NETWORKS,
                                  [Operations.LIST_MISMATCHES.value]),
     constants.PORTS: Resource(constants.PORTS,
@@ -134,7 +141,9 @@ nsxv3_resources = {
                                     [Operations.LIST.value]),
     constants.RATE_LIMIT: Resource(constants.RATE_LIMIT,
                                    [Operations.SHOW.value,
-                                    Operations.NSX_UPDATE.value])
+                                    Operations.NSX_UPDATE.value]),
+    constants.CLUSTER: Resource(constants.CLUSTER,
+                                [Operations.SHOW.value])
 }
 
 # Add supported NSX-V resources in this dictionary
@@ -175,10 +184,14 @@ nsxv_resources = {
     constants.ORPHANED_NETWORKS: Resource(constants.ORPHANED_NETWORKS,
                                  [Operations.LIST.value,
                                   Operations.NSX_CLEAN.value]),
+    constants.NSX_PORTGROUPS: Resource(constants.NSX_PORTGROUPS,
+                                       [Operations.LIST.value,
+                                        Operations.NSX_CLEAN.value]),
     constants.SECURITY_GROUPS: Resource(constants.SECURITY_GROUPS,
                                         [Operations.LIST.value,
                                          Operations.FIX_MISMATCH.value,
-                                         Operations.MIGRATE_TO_POLICY.value]),
+                                         Operations.MIGRATE_TO_POLICY.value,
+                                         Operations.UPDATE_LOGGING.value]),
     constants.FIREWALL_NSX_GROUPS: Resource(
         constants.FIREWALL_NSX_GROUPS, [Operations.LIST.value,
                                         Operations.LIST_MISMATCHES.value]),
@@ -186,7 +199,9 @@ nsxv_resources = {
                                           [Operations.LIST.value,
                                            Operations.LIST_MISMATCHES.value,
                                            Operations.NSX_UPDATE.value,
-                                           Operations.NSX_REORDER.value]),
+                                           Operations.NSX_REORDER.value,
+                                           Operations.LIST_UNUSED.value,
+                                           Operations.NSX_CLEAN.value]),
     constants.METADATA: Resource(
         constants.METADATA, [Operations.NSX_UPDATE.value,
                              Operations.NSX_UPDATE_SECRET.value,
@@ -209,15 +224,17 @@ nsxv_resources = {
                                             Operations.DELETE.value]),
     constants.BGP_NEIGHBOUR: Resource(constants.BGP_NEIGHBOUR,
                                       [Operations.CREATE.value,
-                                       Operations.DELETE.value])
+                                       Operations.DELETE.value]),
+    constants.LBAAS: Resource(constants.LBAAS,
+                              [Operations.NSX_UPDATE.value]),
 }
 
 
 # Add supported NSX-TVD resources in this dictionary
-# TODO(asarfaty): add v+v3 resources here too
 nsxtvd_resources = {
     constants.PROJECTS: Resource(constants.PROJECTS,
-                                 [Operations.IMPORT.value]),
+                                 [Operations.IMPORT.value,
+                                  Operations.NSX_MIGRATE_V_V3.value]),
 }
 
 nsxv3_resources_names = list(nsxv3_resources.keys())
