@@ -16,7 +16,6 @@ import contextlib
 
 import mock
 from neutron.api import extensions
-from neutron.db import api as db_api
 from neutron.db import db_base_plugin_v2
 from neutron import quota
 from neutron.tests import base
@@ -24,6 +23,7 @@ from neutron.tests.unit.api import test_extensions
 from neutron.tests.unit.api.v2 import test_base
 from neutron.tests.unit.db import test_db_base_plugin_v2 as test_db_plugin
 from neutron_lib import context
+from neutron_lib.db import api as db_api
 from neutron_lib.plugins import constants
 from neutron_lib.plugins import directory
 from oslo_config import cfg
@@ -55,6 +55,10 @@ class TestExtensionManager(object):
     def get_request_extensions(self):
         return []
 
+    @property
+    def extensions(self):
+        return []
+
 
 class NetworkGatewayExtensionTestCase(base.BaseTestCase):
 
