@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import copy
-import uuid
 
 import mock
 from neutron.extensions import l3
@@ -450,6 +449,12 @@ class TestSecurityGroup(ext_sg.TestSecurityGroups, SecurityGroupsTestCase):
     def test_create_security_group_rule_icmpv6_legacy_protocol_name(self):
         self.skipTest('not supported')
 
+    def test_create_security_group_rule_protocol_as_number_range(self):
+        self.skipTest('not supported')
+
+    def test_create_security_group_rule_protocol_as_number_with_port(self):
+        self.skipTest('not supported')
+
 
 class TestL3ExtensionManager(object):
 
@@ -1085,7 +1090,8 @@ class NeutronNsxOutOfSync(NsxPluginV2TestCase,
             # duplicate every entry in the nat rule dict
             tmp = copy.deepcopy(self.fc._fake_lrouter_nat_dict)
             for (_rule_id, rule) in tmp.items():
-                self.fc._fake_lrouter_nat_dict[uuid.uuid4()] = rule
+                _uuid = uuidutils.generate_uuid()
+                self.fc._fake_lrouter_nat_dict[_uuid] = rule
 
         self._test_remove_router_interface_nsx_out_of_sync(unsync_action)
 
@@ -1104,16 +1110,6 @@ class NeutronNsxOutOfSync(NsxPluginV2TestCase,
         self.assertEqual(router['router']['status'],
                          constants.NET_STATUS_ERROR)
 
-    def test_delete_security_group_not_in_nsx(self):
-        res = self._create_security_group('json', 'name', 'desc')
-        sec_group = self.deserialize('json', res)
-        self.fc._fake_securityprofile_dict.clear()
-        req = self.new_delete_request(
-            'security-groups',
-            sec_group['security_group']['id'])
-        res = req.get_response(self.ext_api)
-        self.assertEqual(res.status_int, 204)
-
 
 class DHCPOptsTestCase(test_dhcpopts.TestExtraDhcpOpt, NsxPluginV2TestCase):
 
