@@ -20,6 +20,7 @@ from neutron.tests import base
 from neutron_lbaas.services.loadbalancer import data_models as lb_models
 from neutron_lib import context
 from neutron_lib import exceptions as n_exc
+from oslo_config import cfg
 
 from vmware_nsx.db import nsxv_db
 from vmware_nsx.plugins.nsx_v.vshield import vcns_driver
@@ -28,6 +29,7 @@ from vmware_nsx.services.lbaas.nsx_v import lbaas_common as lb_common
 
 
 LB_VIP = '10.0.0.10'
+LB_SUBNET = 'some-subnet'
 LB_EDGE_ID = 'edge-x'
 LB_ID = 'xxx-xxx'
 LB_TENANT_ID = 'yyy-yyy'
@@ -49,7 +51,8 @@ EDGE_VIP_ID = 'vip-aaa'
 EDGE_VIP_DEF = {'protocol': 'http', 'name': 'vip_' + LISTENER_ID,
                 'connectionLimit': 0, 'defaultPoolId': None,
                 'ipAddress': LB_VIP, 'port': 80, 'accelerationEnabled': False,
-                'applicationProfileId': EDGE_APP_PROFILE_ID, 'description': ''}
+                'applicationProfileId': EDGE_APP_PROFILE_ID, 'description': '',
+                'enabled': True}
 LISTENER_BINDING = {'loadbalancer_id': LB_ID,
                     'listener_id': LISTENER_ID,
                     'app_profile_id': EDGE_APP_PROFILE_ID,
@@ -111,11 +114,12 @@ class BaseTestEdgeLbaasV2(base.BaseTestCase):
         self._patch_lb_plugin(self.lbv2_driver, self._tested_entity)
 
         self.lb = lb_models.LoadBalancer(LB_ID, LB_TENANT_ID, 'lb-name', '',
-                                         'some-subnet', 'port-id', LB_VIP)
+                                         LB_SUBNET, 'port-id', LB_VIP)
         self.listener = lb_models.Listener(LISTENER_ID, LB_TENANT_ID,
                                            'l-name', '', None, LB_ID,
                                            'HTTP', protocol_port=80,
-                                           loadbalancer=self.lb)
+                                           loadbalancer=self.lb,
+                                           admin_state_up=True)
         self.sess_persist = lb_models.SessionPersistence(type='HTTP_COOKIE')
         self.pool = lb_models.Pool(POOL_ID, LB_TENANT_ID, 'pool-name', '',
                                    None, 'HTTP', 'ROUND_ROBIN',
@@ -168,17 +172,29 @@ class BaseTestEdgeLbaasV2(base.BaseTestCase):
         setattr(lb_plugin, manager, self.real_manager)
 
 
-class TestEdgeLbaasV2Loadbalancer(BaseTestEdgeLbaasV2):
+class TestEdgeLbaasV2LoadbalancerOnRtr(BaseTestEdgeLbaasV2):
     def setUp(self):
-        super(TestEdgeLbaasV2Loadbalancer, self).setUp()
+        super(TestEdgeLbaasV2LoadbalancerOnRtr, self).setUp()
+        cfg.CONF.set_override('use_routers_as_lbaas_platform',
+                              self._deploy_on_router, group="nsxv")
 
     @property
     def _tested_entity(self):
         return 'load_balancer'
 
+    @property
+    def _edge_getter(self):
+        return 'get_lbaas_edge_id_for_subnet'
+
+    @property
+    def _deploy_on_router(self):
+        return True
+
     def test_create(self):
-        with mock.patch.object(lb_common, 'get_lbaas_edge_id'
+        with mock.patch.object(lb_common, self._edge_getter
                                ) as mock_get_edge, \
+            mock.patch.object(lb_common, 'add_vip_as_secondary_ip'
+                              ) as mock_vip_sec_ip, \
             mock.patch.object(lb_common, 'add_vip_fw_rule'
                               ) as mock_add_vip_fwr, \
             mock.patch.object(lb_common, 'set_lb_firewall_default_rule'
@@ -195,48 +211,18 @@ class TestEdgeLbaasV2Loadbalancer(BaseTestEdgeLbaasV2):
             mock_get_lb_binding_by_edge.return_value = []
             self.edge_driver.loadbalancer.create(self.context, self.lb)
 
-            mock_add_vip_fwr.assert_called_with(self.edge_driver.vcns,
-                                                LB_EDGE_ID,
-                                                LB_ID,
-                                                LB_VIP)
-            mock_db_binding.assert_called_with(self.context.session,
-                                               LB_ID,
-                                               LB_EDGE_ID,
-                                               LB_VIP_FWR_ID,
-                                               LB_VIP)
-            mock_set_fw_rule.assert_called_with(
-                self.edge_driver.vcns, LB_EDGE_ID, 'accept')
-            mock_get_edge.assert_called_with(mock.ANY, mock.ANY, LB_ID, LB_VIP,
-                                             mock.ANY, LB_TENANT_ID, 'compact')
-            mock_successful_completion = (
-                self.lbv2_driver.load_balancer.successful_completion)
-            mock_successful_completion.assert_called_with(self.context,
-                                                          self.lb)
-            mock_enable_edge_acceleration.assert_called_with(
-                self.edge_driver.vcns, LB_EDGE_ID)
-
-    def test_create_with_flavor(self):
-        flavor_name = 'large'
-        with mock.patch.object(lb_common, 'get_lbaas_edge_id'
-                               ) as mock_get_edge, \
-            mock.patch.object(lb_common, 'add_vip_fw_rule'
-                              ) as mock_add_vip_fwr, \
-            mock.patch.object(lb_common, 'set_lb_firewall_default_rule'
-                              ) as mock_set_fw_rule, \
-            mock.patch.object(lb_common, 'enable_edge_acceleration'
-                              ) as mock_enable_edge_acceleration, \
-            mock.patch.object(nsxv_db,
-                              'get_nsxv_lbaas_loadbalancer_binding_by_edge'
-                              ) as mock_get_lb_binding_by_edge, \
-            mock.patch.object(nsxv_db, 'add_nsxv_lbaas_loadbalancer_binding'
-                              ) as mock_db_binding,\
-            mock.patch('neutron.services.flavors.flavors_plugin.FlavorsPlugin.'
-                      'get_flavor', return_value={'name': flavor_name}):
-            mock_get_edge.return_value = LB_EDGE_ID
-            mock_add_vip_fwr.return_value = LB_VIP_FWR_ID
-            mock_get_lb_binding_by_edge.return_value = []
-            self.lb.flavor_id = 'dummy'
-            self.edge_driver.loadbalancer.create(self.context, self.lb)
+            if self._deploy_on_router:
+                mock_vip_sec_ip.assert_called_with(self.edge_driver.vcns,
+                                                   LB_EDGE_ID,
+                                                   LB_VIP)
+                mock_get_edge.assert_called_with(mock.ANY, mock.ANY,
+                                                 LB_SUBNET, LB_TENANT_ID)
+            else:
+                mock_set_fw_rule.assert_called_with(
+                    self.edge_driver.vcns, LB_EDGE_ID, 'accept')
+                mock_get_edge.assert_called_with(mock.ANY, mock.ANY, LB_ID,
+                                                 LB_VIP, mock.ANY,
+                                                 LB_TENANT_ID, 'compact')
 
             mock_add_vip_fwr.assert_called_with(self.edge_driver.vcns,
                                                 LB_EDGE_ID,
@@ -247,49 +233,24 @@ class TestEdgeLbaasV2Loadbalancer(BaseTestEdgeLbaasV2):
                                                LB_EDGE_ID,
                                                LB_VIP_FWR_ID,
                                                LB_VIP)
-            mock_set_fw_rule.assert_called_with(
-                self.edge_driver.vcns, LB_EDGE_ID, 'accept')
-            mock_get_edge.assert_called_with(
-                mock.ANY, mock.ANY, LB_ID, LB_VIP,
-                mock.ANY, LB_TENANT_ID, flavor_name)
             mock_successful_completion = (
                 self.lbv2_driver.load_balancer.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          self.lb)
+                                                          self.lb,
+                                                          delete=False)
             mock_enable_edge_acceleration.assert_called_with(
                 self.edge_driver.vcns, LB_EDGE_ID)
-            self.lb.flavor_id = None
-
-    def test_create_with_illegal_flavor(self):
-        flavor_name = 'no_size'
-        with mock.patch.object(lb_common, 'get_lbaas_edge_id'
-                               ) as mock_get_edge, \
-            mock.patch.object(lb_common, 'add_vip_fw_rule'
-                              ) as mock_add_vip_fwr, \
-            mock.patch.object(nsxv_db,
-                              'get_nsxv_lbaas_loadbalancer_binding_by_edge'
-                              ) as mock_get_lb_binding_by_edge, \
-            mock.patch('neutron.services.flavors.flavors_plugin.FlavorsPlugin.'
-                      'get_flavor', return_value={'name': flavor_name}):
-            mock_get_edge.return_value = LB_EDGE_ID
-            mock_add_vip_fwr.return_value = LB_VIP_FWR_ID
-            mock_get_lb_binding_by_edge.return_value = []
-            self.lb.flavor_id = 'dummy'
-            self.assertRaises(
-                n_exc.InvalidInput,
-                self.edge_driver.loadbalancer.create,
-                self.context, self.lb)
-            self.lb.flavor_id = None
 
     def test_update(self):
         new_lb = lb_models.LoadBalancer(LB_ID, 'yyy-yyy', 'lb-name', 'heh-huh',
-                                    'some-subnet', 'port-id', LB_VIP)
+                                        LB_SUBNET, 'port-id', LB_VIP)
 
         self.edge_driver.loadbalancer.update(self.context, self.lb, new_lb)
 
         mock_successful_completion = (
             self.lbv2_driver.load_balancer.successful_completion)
-        mock_successful_completion.assert_called_with(self.context, new_lb)
+        mock_successful_completion.assert_called_with(self.context, new_lb,
+                                                      delete=False)
 
     def test_delete_old(self):
         with mock.patch.object(nsxv_db, 'get_nsxv_lbaas_loadbalancer_binding'
@@ -366,6 +327,86 @@ class TestEdgeLbaasV2Loadbalancer(BaseTestEdgeLbaasV2):
         pass
 
 
+class TestEdgeLbaasV2LoadbalancerOnEdge(TestEdgeLbaasV2LoadbalancerOnRtr):
+    @property
+    def _edge_getter(self):
+        return 'get_lbaas_edge_id'
+
+    @property
+    def _deploy_on_router(self):
+        return False
+
+    def setUp(self):
+        super(TestEdgeLbaasV2LoadbalancerOnEdge, self).setUp()
+
+    def test_create_with_flavor(self):
+        flavor_name = 'large'
+        with mock.patch.object(lb_common, 'get_lbaas_edge_id'
+                               ) as mock_get_edge, \
+            mock.patch.object(lb_common, 'add_vip_fw_rule'
+                              ) as mock_add_vip_fwr, \
+            mock.patch.object(lb_common, 'set_lb_firewall_default_rule'
+                              ) as mock_set_fw_rule, \
+            mock.patch.object(lb_common, 'enable_edge_acceleration'
+                              ) as mock_enable_edge_acceleration, \
+            mock.patch.object(nsxv_db,
+                              'get_nsxv_lbaas_loadbalancer_binding_by_edge'
+                              ) as mock_get_lb_binding_by_edge, \
+            mock.patch.object(nsxv_db, 'add_nsxv_lbaas_loadbalancer_binding'
+                              ) as mock_db_binding,\
+            mock.patch('neutron.services.flavors.flavors_plugin.FlavorsPlugin.'
+                      'get_flavor', return_value={'name': flavor_name}):
+            mock_get_edge.return_value = LB_EDGE_ID
+            mock_add_vip_fwr.return_value = LB_VIP_FWR_ID
+            mock_get_lb_binding_by_edge.return_value = []
+            self.lb.flavor_id = 'dummy'
+            self.edge_driver.loadbalancer.create(self.context, self.lb)
+
+            mock_add_vip_fwr.assert_called_with(self.edge_driver.vcns,
+                                                LB_EDGE_ID,
+                                                LB_ID,
+                                                LB_VIP)
+            mock_db_binding.assert_called_with(self.context.session,
+                                               LB_ID,
+                                               LB_EDGE_ID,
+                                               LB_VIP_FWR_ID,
+                                               LB_VIP)
+            mock_set_fw_rule.assert_called_with(
+                self.edge_driver.vcns, LB_EDGE_ID, 'accept')
+            mock_get_edge.assert_called_with(
+                mock.ANY, mock.ANY, LB_ID, LB_VIP,
+                mock.ANY, LB_TENANT_ID, flavor_name)
+            mock_successful_completion = (
+                self.lbv2_driver.load_balancer.successful_completion)
+            mock_successful_completion.assert_called_with(self.context,
+                                                          self.lb,
+                                                          delete=False)
+            mock_enable_edge_acceleration.assert_called_with(
+                self.edge_driver.vcns, LB_EDGE_ID)
+            self.lb.flavor_id = None
+
+    def test_create_with_illegal_flavor(self):
+        flavor_name = 'no_size'
+        with mock.patch.object(lb_common, 'get_lbaas_edge_id'
+                               ) as mock_get_edge, \
+            mock.patch.object(lb_common, 'add_vip_fw_rule'
+                              ) as mock_add_vip_fwr, \
+            mock.patch.object(nsxv_db,
+                              'get_nsxv_lbaas_loadbalancer_binding_by_edge'
+                              ) as mock_get_lb_binding_by_edge, \
+            mock.patch('neutron.services.flavors.flavors_plugin.FlavorsPlugin.'
+                      'get_flavor', return_value={'name': flavor_name}):
+            mock_get_edge.return_value = LB_EDGE_ID
+            mock_add_vip_fwr.return_value = LB_VIP_FWR_ID
+            mock_get_lb_binding_by_edge.return_value = []
+            self.lb.flavor_id = 'dummy'
+            self.assertRaises(
+                n_exc.InvalidInput,
+                self.edge_driver.loadbalancer.create,
+                self.context, self.lb)
+            self.lb.flavor_id = None
+
+
 class TestEdgeLbaasV2Listener(BaseTestEdgeLbaasV2):
     def setUp(self):
         super(TestEdgeLbaasV2Listener, self).setUp()
@@ -403,13 +444,15 @@ class TestEdgeLbaasV2Listener(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.listener.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          self.listener)
+                                                          self.listener,
+                                                          delete=False)
 
     def test_update(self):
         new_listener = lb_models.Listener(LISTENER_ID, LB_TENANT_ID,
                                           'l-name', '', None, LB_ID,
                                           'HTTP', protocol_port=8000,
-                                          loadbalancer=self.lb)
+                                          loadbalancer=self.lb,
+                                          admin_state_up=True)
         new_listener.default_pool = self.pool
 
         with mock.patch.object(nsxv_db, 'get_nsxv_lbaas_listener_binding'
@@ -439,7 +482,8 @@ class TestEdgeLbaasV2Listener(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.listener.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          new_listener)
+                                                          new_listener,
+                                                          delete=False)
 
     def test_delete(self):
         with mock.patch.object(nsxv_db, 'get_nsxv_lbaas_listener_binding'
@@ -511,7 +555,8 @@ class TestEdgeLbaasV2Pool(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.pool.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          self.pool)
+                                                          self.pool,
+                                                          delete=False)
 
     def test_update(self):
         new_pool = lb_models.Pool(POOL_ID, LB_TENANT_ID, 'pool-name', '',
@@ -550,7 +595,8 @@ class TestEdgeLbaasV2Pool(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.pool.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          new_pool)
+                                                          new_pool,
+                                                          delete=False)
 
     def test_delete(self):
         with mock.patch.object(nsxv_db, 'get_nsxv_lbaas_loadbalancer_binding'
@@ -565,11 +611,14 @@ class TestEdgeLbaasV2Pool(BaseTestEdgeLbaasV2):
                               ) as mock_del_pool, \
             mock.patch.object(nsxv_db, 'del_nsxv_lbaas_pool_binding'
                               ) as mock_del_binding,\
+            mock.patch.object(lb_common, 'is_lb_on_router_edge'
+                              ) as mock_lb_router, \
             mock.patch.object(self.edge_driver.vcns, 'update_app_profile'
                               ):
             mock_get_lb_binding.return_value = LB_BINDING
             mock_get_pool_binding.return_value = POOL_BINDING
             mock_get_listener_binding.return_value = LISTENER_BINDING
+            mock_lb_router.return_value = False
 
             self.edge_driver.pool.delete(self.context, self.pool)
 
@@ -617,7 +666,8 @@ class TestEdgeLbaasV2Member(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.member.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          self.member)
+                                                          self.member,
+                                                          delete=False)
 
     def test_update(self):
         new_member = lb_models.Member(MEMBER_ID, LB_TENANT_ID, POOL_ID,
@@ -650,7 +700,8 @@ class TestEdgeLbaasV2Member(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.member.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          new_member)
+                                                          new_member,
+                                                          delete=False)
 
     def test_delete(self):
         with mock.patch.object(nsxv_db, 'get_nsxv_lbaas_loadbalancer_binding'
@@ -661,12 +712,15 @@ class TestEdgeLbaasV2Member(BaseTestEdgeLbaasV2):
                               ) as mock_get_pool, \
             mock.patch.object(self.core_plugin, 'get_ports'
                               ) as mock_get_ports, \
+            mock.patch.object(lb_common, 'is_lb_on_router_edge'
+                              ) as mock_lb_router, \
             mock.patch.object(lb_common, 'delete_lb_interface'
                               ) as mock_del_lb_iface, \
             mock.patch.object(self.edge_driver.vcns, 'update_pool'
                               ) as mock_update_pool:
             mock_get_lb_binding.return_value = LB_BINDING
             mock_get_pool_binding.return_value = POOL_BINDING
+            mock_lb_router.return_value = False
             edge_pool_def = EDGE_POOL_DEF.copy()
             edge_pool_def['member'] = [EDGE_MEMBER_DEF]
             mock_get_pool.return_value = (None, edge_pool_def)
@@ -728,7 +782,8 @@ class TestEdgeLbaasV2HealthMonitor(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.health_monitor.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          self.hm)
+                                                          self.hm,
+                                                          delete=False)
 
     def test_update(self):
         new_hm = lb_models.HealthMonitor(HM_ID, LB_TENANT_ID, 'PING', 3, 3,
@@ -755,7 +810,8 @@ class TestEdgeLbaasV2HealthMonitor(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.health_monitor.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          new_hm)
+                                                          new_hm,
+                                                          delete=False)
 
     def test_delete(self):
         with mock.patch.object(nsxv_db, 'get_nsxv_lbaas_loadbalancer_binding'
@@ -840,7 +896,8 @@ class TestEdgeLbaasV2L7Policy(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.l7policy.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          self.l7policy)
+                                                          self.l7policy,
+                                                          delete=False)
 
     def test_update(self):
         url = 'http://www.test.com'
@@ -883,7 +940,8 @@ class TestEdgeLbaasV2L7Policy(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.l7policy.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          new_pol)
+                                                          new_pol,
+                                                          delete=False)
 
     def test_delete(self):
         with mock.patch.object(nsxv_db, 'get_nsxv_lbaas_l7policy_binding'
