@@ -249,7 +249,9 @@ class FakeVcns(object):
         response = {
             'label': 'vNic_1',
             'name': 'internal1',
-            'addressGroups': {'addressGroups': []},
+            'addressGroups': {
+                'addressGroups': [{'primaryAddress': '1.1.1.1'}]},
+            'portgroupId': '1',
             'mtu': 1500,
             'type': 'trunk',
             'subInterfaces': {'subInterfaces': []},
@@ -788,6 +790,9 @@ class FakeVcns(object):
             response['config'] = self._fake_loadbalancer_config[edge_id]
         return self.return_helper(header, response)
 
+    def get_loadbalancer_statistics(self, edge_id):
+        return [{}, {}]
+
     def update_ipsec_config(self, edge_id, ipsec_config):
         self.fake_ipsecvpn_dict[edge_id] = ipsec_config
         header = {'status': 204}
@@ -1046,8 +1051,8 @@ class FakeVcns(object):
 
     def get_section_id(self, section_name):
         for k, v in self._sections.items():
-            if (k not in ('section_ids', 'rule_ids', 'names')
-                and v['name'] == section_name):
+            if (k not in ('section_ids', 'rule_ids', 'names') and
+                v['name'] == section_name):
                 return k
 
     def update_section_by_id(self, id, type, request):
