@@ -21,8 +21,8 @@ from neutron_lib import exceptions as n_exc
 
 from vmware_nsx.db import db as nsx_db
 from vmware_nsx.services.lbaas import base_mgr
-from vmware_nsx.services.lbaas.nsx_v3 import lb_driver_v2
-from vmware_nsx.services.lbaas.nsx_v3 import lb_utils
+from vmware_nsx.services.lbaas.nsx_v3.implementation import lb_utils
+from vmware_nsx.services.lbaas.nsx_v3.v2 import lb_driver_v2
 
 
 LB_VIP = '10.0.0.10'
@@ -124,7 +124,7 @@ class BaseTestEdgeLbaasV2(base.BaseTestCase):
         self.lb = lb_models.LoadBalancer(LB_ID, LB_TENANT_ID, 'lb1', '',
                                          'some-subnet', 'port-id', LB_VIP)
         self.listener = lb_models.Listener(LISTENER_ID, LB_TENANT_ID,
-                                           'listener1', '', None, LB_ID,
+                                           'listener1', 'Dummy', None, LB_ID,
                                            'HTTP', protocol_port=80,
                                            loadbalancer=self.lb)
         self.https_listener = lb_models.Listener(
@@ -213,7 +213,8 @@ class TestEdgeLbaasV2Loadbalancer(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.load_balancer.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          self.lb)
+                                                          self.lb,
+                                                          delete=False)
 
     def test_update(self):
         new_lb = lb_models.LoadBalancer(LB_ID, 'yyy-yyy', 'lb1-new',
@@ -224,7 +225,8 @@ class TestEdgeLbaasV2Loadbalancer(BaseTestEdgeLbaasV2):
 
         mock_successful_completion = (
             self.lbv2_driver.load_balancer.successful_completion)
-        mock_successful_completion.assert_called_with(self.context, new_lb)
+        mock_successful_completion.assert_called_with(self.context, new_lb,
+                                                      delete=False)
 
     def test_delete(self):
         with mock.patch.object(nsx_db, 'get_nsx_lbaas_loadbalancer_binding'
@@ -296,7 +298,8 @@ class TestEdgeLbaasV2Listener(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.listener.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          listener)
+                                                          listener,
+                                                          delete=False)
 
     def test_create_http_listener(self):
         self._create_listener()
@@ -336,7 +339,8 @@ class TestEdgeLbaasV2Listener(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.listener.successful_completion)
             mock_successful_completion.assert_called_with(
-                self.context, self.terminated_https_listener)
+                self.context, self.terminated_https_listener,
+                delete=False)
 
     def test_update(self):
         new_listener = lb_models.Listener(LISTENER_ID, LB_TENANT_ID,
@@ -356,7 +360,8 @@ class TestEdgeLbaasV2Listener(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.listener.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          new_listener)
+                                                          new_listener,
+                                                          delete=False)
 
     def test_delete(self):
         with mock.patch.object(nsx_db, 'get_nsx_lbaas_listener_binding'
@@ -426,7 +431,8 @@ class TestEdgeLbaasV2Pool(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.pool.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          self.pool)
+                                                          self.pool,
+                                                          delete=False)
 
     def test_update(self):
         new_pool = lb_models.Pool(POOL_ID, LB_TENANT_ID, 'pool-name', '',
@@ -441,7 +447,8 @@ class TestEdgeLbaasV2Pool(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.pool.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          new_pool)
+                                                          new_pool,
+                                                          delete=False)
 
     def test_delete(self):
         with mock.patch.object(nsx_db, 'get_nsx_lbaas_pool_binding'
@@ -527,7 +534,8 @@ class TestEdgeLbaasV2Member(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.member.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          self.member)
+                                                          self.member,
+                                                          delete=False)
 
     def test_create_lbs_no_router_gateway(self):
         with mock.patch.object(lb_utils, 'validate_lb_subnet'
@@ -583,7 +591,8 @@ class TestEdgeLbaasV2Member(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.member.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          new_member)
+                                                          new_member,
+                                                          delete=False)
 
     def test_delete(self):
         with mock.patch.object(nsx_db, 'get_nsx_lbaas_pool_binding'
@@ -640,16 +649,29 @@ class TestEdgeLbaasV2HealthMonitor(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.health_monitor.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          self.hm)
+                                                          self.hm,
+                                                          delete=False)
 
     def test_update(self):
-        new_hm = lb_models.HealthMonitor(HM_ID, LB_TENANT_ID, 'PING', 3, 3,
-                                         3, pool=self.pool)
-        self.edge_driver.healthmonitor.update(self.context, self.hm, new_hm)
+        with mock.patch.object(self.monitor_client, 'update'
+                               ) as mock_update_monitor, \
+            mock.patch.object(nsx_db, 'get_nsx_lbaas_monitor_binding'
+                              ) as mock_get_monitor_binding:
+            mock_get_monitor_binding.return_value = HM_BINDING
+            new_hm = lb_models.HealthMonitor(
+                HM_ID, LB_TENANT_ID, 'PING', 5, 5,
+                5, pool=self.pool, name='new_name')
+            self.edge_driver.healthmonitor.update(
+                self.context, self.hm, new_hm)
+            mock_update_monitor.assert_called_with(
+                LB_MONITOR_ID, display_name=mock.ANY,
+                fall_count=5, interval=5, timeout=5,
+                resource_type='LbIcmpMonitor')
 
-        mock_successful_completion = (
-            self.lbv2_driver.health_monitor.successful_completion)
-        mock_successful_completion.assert_called_with(self.context, new_hm)
+            mock_successful_completion = (
+                self.lbv2_driver.health_monitor.successful_completion)
+            mock_successful_completion.assert_called_with(self.context, new_hm,
+                                                          delete=False)
 
     def test_delete(self):
         with mock.patch.object(nsx_db, 'get_nsx_lbaas_monitor_binding'
@@ -712,7 +734,8 @@ class TestEdgeLbaasV2L7Policy(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.l7policy.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          self.l7policy)
+                                                          self.l7policy,
+                                                          delete=False)
 
     def test_update(self):
         new_l7policy = lb_models.L7Policy(L7POLICY_ID, LB_TENANT_ID,
@@ -757,7 +780,8 @@ class TestEdgeLbaasV2L7Policy(BaseTestEdgeLbaasV2):
             mock_successful_completion = (
                 self.lbv2_driver.l7policy.successful_completion)
             mock_successful_completion.assert_called_with(self.context,
-                                                          new_l7policy)
+                                                          new_l7policy,
+                                                          delete=False)
 
     def test_delete(self):
         with mock.patch.object(nsx_db, 'get_nsx_lbaas_l7policy_binding'
