@@ -16,18 +16,18 @@
 import abc
 
 import mock
+from oslo_config import cfg
+from oslo_log import _options
+from oslo_log import log as logging
+from oslo_utils import uuidutils
+import six
+
 from neutron.common import config as neutron_config
 from neutron.db import servicetype_db  # noqa
 from neutron.quota import resource_registry
 from neutron.tests import base
 from neutron_lib.callbacks import registry
 from neutron_lib.plugins import constants
-from oslo_config import cfg
-from oslo_log import _options
-from oslo_log import log as logging
-from oslo_utils import uuidutils
-import six
-from vmware_nsxlib.v3 import resources as nsx_v3_resources
 
 from vmware_nsx._i18n import _
 from vmware_nsx.common import config  # noqa
@@ -39,6 +39,8 @@ from vmware_nsx.shell import resources
 from vmware_nsx.tests import unit as vmware
 from vmware_nsx.tests.unit.nsx_v import test_plugin as test_v_plugin
 from vmware_nsx.tests.unit.nsx_v3 import test_plugin as test_v3_plugin
+from vmware_nsxlib.v3 import core_resources
+from vmware_nsxlib.v3 import resources as nsx_v3_resources
 
 LOG = logging.getLogger(__name__)
 NSX_INI_PATH = vmware.get_fake_conf('nsx.ini.test')
@@ -218,7 +220,8 @@ class TestNsxvAdminUtils(AbstractTestAdminUtils,
                 "security-group-id=sg-1",
                 "dvs-id=dvs-1",
                 "moref=virtualwire-1",
-                "teamingpolicy=LACP_ACTIVE"
+                "teamingpolicy=LACP_ACTIVE",
+                "log-allowed-traffic=true"
                 ]
         self._test_resources_with_args(
             resources.nsxv_resources, args)
@@ -244,16 +247,15 @@ class TestNsxv3AdminUtils(AbstractTestAdminUtils,
         # mock resources
         for cls in (nsx_v3_resources.LogicalPort,
                     nsx_v3_resources.LogicalDhcpServer,
-                    nsx_v3_resources.LogicalRouter,
-                    nsx_v3_resources.SwitchingProfile):
+                    core_resources.NsxLibLogicalRouter,
+                    core_resources.NsxLibSwitchingProfile):
 
-            self._patch_object(cls, '__init__', return_value=None)
             self._patch_object(cls, 'list', return_value={'results': []})
             self._patch_object(cls, 'get',
                                return_value={'id': uuidutils.generate_uuid()})
             self._patch_object(cls, 'update')
 
-        self._patch_object(nsx_v3_resources.SwitchingProfile,
+        self._patch_object(core_resources.NsxLibSwitchingProfile,
                            'find_by_display_name',
                            return_value=[{'id': uuidutils.generate_uuid()}])
         super(TestNsxv3AdminUtils, self)._init_mock_plugin()
@@ -280,7 +282,8 @@ class TestNsxv3AdminUtils(AbstractTestAdminUtils,
                 "metadata_proxy_uuid=e5b9b249-0034-4729-8ab6-fe4dacaa3a12",
                 "nsx-id=e5b9b249-0034-4729-8ab6-fe4dacaa3a12",
                 "availability-zone=default",
-                "server-ip=1.1.1.1"
+                "server-ip=1.1.1.1",
+                "log-allowed-traffic=true"
                 ]
         # Create some neutron objects for the utilities to run on
         self._create_router()
